package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````\"@```````!``````````%C!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````$`9````````0!D`````````
M$`````````$````%`````"``````````(``````````@````````?4$`````
M``!]00`````````0`````````0````0`````<`````````!P`````````'``
M``````#(2````````,A(`````````!`````````!````!@```-"[````````
MT,L```````#0RP```````%@$````````@`0`````````$`````````(````&
M````X+L```````#@RP```````.#+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``!@L0```````&"Q````````8+$```````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````T+L```````#0RP```````-#+````
M````,`0````````P!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`1":=8AEQDG32H[DU
MWA_=4=X!S\H$````$`````$```!'3E4```````,````"```````````````1
M````0@````0````(````(!`0``5`!(0H`@`$@(8`A(()```)(`0(B(`10;H`
M`@@`````0@```$4```!(````20```%````!1````4@````````!4````50``
M`%8```!7````60```%L``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@:PE#UF>OS&9"
M1=7LB0=PTS-BV^T5C"7,#3J7"WZIG)O19<YMX*<""FL:GE"CX/M)````````
M`````````````````````````````(T"```2````````````````````````
M`/0!```2`````````````````````````(P````1````````````````````
M`````'0"```2`````````````````````````$L!```2````````````````
M`````````,\!```2`````````````````````````#`"```2````````````
M``````````````$````@`````````````````````````,@"```2````````
M`````````````````&<````2`````````````````````````+,````2````
M`````````````````````)0````2`````````````````````````&T"```2
M`````````````````````````+\"```2`````````````````````````.0!
M```2`````````````````````````-\````2````````````````````````
M`.\````2`````````````````````````#T!```2````````````````````
M`````'$!```2`````````````````````````(H````1````````````````
M`````````&<#```2`````````````````````````!`````@````````````
M`````````````*4"```2`````````````````````````)("```2````````
M`````````````````,H````2`````````````````````````"P````@````
M`````````````````````)T````2`````````````````````````+@````2
M`````````````````````````)<"```2`````````````````````````/4`
M```6``````````````````````````@!```2````````````````````````
M`$,"```2`````````````````````````",!```2````````````````````
M`````+`"```2`````````````````````````)L!```2````````````````
M`````````-T!```2`````````````````````````*H!```2````````````
M`````````````%(!```2`````````````````````````#0!```2````````
M`````````````````&$!```2`````````````````````````'\!```2````
M`````````````````````'\"```2`````````````````````````+<!```2
M`````````````````````````(8!```2`````````````````````````!4"
M```2`````````````````````````'D````2````````````````````````
M`)0!```2`````````````````````````(T!```2````````````````````
M`````)P````2`````````````````````````*,!```2````````````````
M```````````"```2`````````````````````````&$"```2````````````
M`````````````*L````2`````````````````````````.8````2````````
M`````````````````-$````2`````````````````````````,@!```1````
M`````````````````````%0"```1`````````````````````````*0````2
M`````````````````````````&D!```2`````````````````````````!@!
M```2`````````````````````````"$"```2````````````````````````
M`$8````2`````````````````````````'@!```2````````````````````
M`````,`````2`````````````````````````+$!```2````````````````
M`````````'`#```2`!``0%P```````#;`````````,4#```2`!``0%,`````
M``#@!@```````%,````2`!``X"8````````0`@```````.<"```2`!``T$@`
M```````)``````````4#```2`!``(%H````````@`@```````.L#```2`!``
MX$@````````2`@```````*L#```0`!H`*-```````````````````/@"```2
M`!```$L````````F`````````!L#```2`!``D%$```````!I`````````'P#
M```1`!(``'`````````$`````````)@#```2`!``<%T```````"?`0``````
M`*,#```2`!``P$<````````I`````````,`#```0`!H`4-``````````````
M`````-D#```2`!``,%(````````+`0```````(L#```0`!D``-``````````
M`````````#\#```2`!``,$L```````!!`0```````-(#```0`!D`*-``````
M`````````````/@#```1`!D`(-`````````(`````````)$#```2`!``\"@`
M```````F`````````+<#```2`!``(%T```````!)`````````(T#```@`!D`
M`-```````````````````%4#```2`!```%(````````A`````````%@````B
M`````````````````````````"D#```2`!``\$<```````#2`````````$L#
M```2`!``$%\```````!+`@````````($```2`!``@$P````````$!0``````
M``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?
M7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F
M86EL`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&QS965K-C0`
M<F5A9`!O<&5N9&ER`')E861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U
M;FQI;FL`8VQO<V5D:7(`<FUD:7(`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?
M1'EN84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI
M;FL`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`;65M;6]V
M90!R96%L;&]C`&=E='!I9`!M96UC<'D`<W1R8VAR`'-T<F1U<`!S=')T;VL`
M<W1R8VUP`'-T<G)C:'(`9V5T=6ED`'-T<G-T<@!M:V1I<@!?7V5R<FYO7VQO
M8V%T:6]N`'-T9&5R<@!?7V9P<FEN=&9?8VAK`&]P96XV-`!097)L7V=V7V9E
M=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M
M9U]S970`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E
M<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U;@!E>&ET`&QI
M8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D
M:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S
M7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET
M7V5N=@!'3$E"0U\R+C$T`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N
M,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR+C4````!``$`
M`@`!``(``P`!``$``@`$``(``@`"``$``0`"``(``0`"``(``@`!``$``@`"
M``$`!0`"``$``0`!``$``0`!``(``@`"``$``@`"``(``0`"``(``0`&``(`
M`@`%``(``0`!``(``@`#``(``0`"``(``0`!``<`"``"``(``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``$``0`!````
M`0`'`-T"```0`````````)21E@8```@`#P0``!````"TD98&```'`!H$```0
M````%&EI#0``!@`E!```$````+.1E@8```4`+P0``!````!R&6D)```$`#H$
M```0````=!EI"0```P!&!```$````'4::0D```(`4@0```````#0RP``````
M``@`````````T"D```````#8RP````````@`````````D"D````````(T```
M``````@`````````"-`````````@T`````````@`````````V'(```````"@
MSP````````8````#``````````````"HSP````````8````'````````````
M``"PSP````````8````(``````````````"XSP````````8````6````````
M``````#`SP````````8````:``````````````#(SP````````8```!8````
M``````````#0SP```````!(````>``````````````#8SP````````8````?
M``````````````#@SP````````8````@``````````````#HSP````````8`
M```X``````````````#PSP````````8````Y``````````````#XSP``````
M``8````^``````````````#XS0````````<````!````````````````S@``
M``````<````"```````````````(S@````````<````$```````````````0
MS@````````<````%```````````````8S@````````<````&````````````
M```@S@````````<````)```````````````HS@````````<````*````````
M```````PS@````````<````+```````````````XS@````````<````,````
M``````````!`S@````````<````-``````````````!(S@````````<````.
M``````````````!0S@````````<````/``````````````!8S@````````<`
M```0``````````````!@S@````````<````1``````````````!HS@``````
M``<````2``````````````!PS@````````<````3``````````````!XS@``
M``````<````5``````````````"`S@````````<````7``````````````"(
MS@````````<````8``````````````"0S@````````<````9````````````
M``"8S@````````<````;``````````````"@S@````````<````<````````
M``````"HS@````````<````=``````````````"PS@````````<````A````
M``````````"XS@````````<````B``````````````#`S@````````<````C
M``````````````#(S@````````<````D``````````````#0S@````````<`
M```E``````````````#8S@````````<````F``````````````#@S@``````
M``<````G``````````````#HS@````````<````H``````````````#PS@``
M``````<````I``````````````#XS@````````<````J````````````````
MSP````````<````K```````````````(SP````````<````L````````````
M```0SP````````<````M```````````````8SP````````<````N````````
M```````@SP````````<````O```````````````HSP````````<````P````
M```````````PSP````````<````Q```````````````XSP````````<````R
M``````````````!`SP````````<````S``````````````!(SP````````<`
M```T``````````````!0SP````````<````U``````````````!8SP``````
M``<````V``````````````!@SP````````<````W``````````````!HSP``
M``````<````Z``````````````!PSP````````<````[``````````````!X
MSP````````<````\``````````````"`SP````````<````]````````````
M``"(SP````````<````_``````````````"0SP````````<```!`````````
M``````"8SP````````<```!!````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&O``!(A<!T`O_02(/$",,``````/\UPJT``/\EQ*T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OK_)3ZL``!F#Q]$``#S#Q[Z_R5>J@``9@\?1```\P\>^O\E5JH``&8/'T0`
M`/,/'OK_)4ZJ``!F#Q]$``#S#Q[Z_R5&J@``9@\?1```\P\>^O\E/JH``&8/
M'T0``/,/'OK_)3:J``!F#Q]$``#S#Q[Z_R4NJ@``9@\?1```\P\>^O\E)JH`
M`&8/'T0``/,/'OK_)1ZJ``!F#Q]$``#S#Q[Z_R46J@``9@\?1```\P\>^O\E
M#JH``&8/'T0``/,/'OK_)0:J``!F#Q]$``#S#Q[Z_R7^J0``9@\?1```\P\>
M^O\E]JD``&8/'T0``/,/'OK_)>ZI``!F#Q]$``#S#Q[Z_R7FJ0``9@\?1```
M\P\>^O\EWJD``&8/'T0``/,/'OK_)=:I``!F#Q]$``#S#Q[Z_R7.J0``9@\?
M1```\P\>^O\EQJD``&8/'T0``/,/'OK_);ZI``!F#Q]$``#S#Q[Z_R6VJ0``
M9@\?1```\P\>^O\EKJD``&8/'T0``/,/'OK_)::I``!F#Q]$``#S#Q[Z_R6>
MJ0``9@\?1```\P\>^O\EEJD``&8/'T0``/,/'OK_)8ZI``!F#Q]$``#S#Q[Z
M_R6&J0``9@\?1```\P\>^O\E?JD``&8/'T0``/,/'OK_)7:I``!F#Q]$``#S
M#Q[Z_R5NJ0``9@\?1```\P\>^O\E9JD``&8/'T0``/,/'OK_)5ZI``!F#Q]$
M``#S#Q[Z_R56J0``9@\?1```\P\>^O\E3JD``&8/'T0``/,/'OK_)4:I``!F
M#Q]$``#S#Q[Z_R4^J0``9@\?1```\P\>^O\E-JD``&8/'T0``/,/'OK_)2ZI
M``!F#Q]$``#S#Q[Z_R4FJ0``9@\?1```\P\>^O\E'JD``&8/'T0``/,/'OK_
M)1:I``!F#Q]$``#S#Q[Z_R4.J0``9@\?1```\P\>^O\E!JD``&8/'T0``/,/
M'OK_)?ZH``!F#Q]$``#S#Q[Z_R7VJ```9@\?1```\P\>^O\E[J@``&8/'T0`
M`/,/'OK_)>:H``!F#Q]$``#S#Q[Z_R7>J```9@\?1```\P\>^O\EUJ@``&8/
M'T0``/,/'OK_)<ZH``!F#Q]$``#S#Q[Z_R7&J```9@\?1```\P\>^O\EOJ@`
M`&8/'T0``/,/'OI54TB#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D
M"&1(BP0E*````$B)1"0H,<#HA/___TB+-86H``!(BSVVJ```2(GRZ"XZ``!(
MBP6WJ```@#@`#X08`0``2(L%AZ@``&1(BP"`B"H$```#BT0D'(UX!(U8`TAC
M_TC!YP/HQO[__TB+3"001(M$)!Q(B<9(B07*J```2(L!2(D&2(T%.$H``$B)
M1@A(C06*J```2(L`2(E&$$B-!2)*``!(B48808/X`0^.)0$``$B#P0A!@\`#
MN`0```"02(LY2&/0@\`!2(/!"$B)/-9$.<!UZDB82(L]6:@``$B)\8G:2,<$
MQ@````!%,<!(C35*'```Z+7[__^)PX7`#X2%````2(L]+*@``$B-;"0DZ'K]
M__\QP$B)[DB-/8%(``#H*1@``$B%P'1Q2(L]!:@``.A8^___Z+/\__](BT0D
M*&1(*P0E*`````^%F@```$B#Q#B)V%M=P^A!_/__2(D%TJ<``$B)QTB%P'1S
MZ)W\__](BP56IP``9$B+$,:"UPD```#IO_[__TB+/:>G``#HFOO__XG#Z6C_
M__](BSV<IP``2(7_=`KHDC,``.EY____2(T]GD<``$B)[NB.%P``2(D%=Z<`
M`$B)QTB%P`^$5____^O2N`0```#I]?[__[\!````Z/7Z___HX/S___,/'OHQ
M[4F)T5Y(B>)(@^3P4%1%,<`QR4B-/=']____%>.F``#T9BX/'X0``````$B-
M/0&G``!(C07ZI@``2#GX=!5(BP5^I@``2(7`=`G_X`\?@`````###Q^`````
M`$B-/=&F``!(C37*I@``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!46F``!(
MA<!T"/_@9@\?1```PP\?@`````#S#Q[Z@#V-I@```'4K54B#/2*F````2(GE
M=`Q(BSU6I@``Z,GY___H9/___\8%9:8```%=PP\?`,,/'X``````\P\>^NEW
M____#Q^``````$%72(G^3(U'.$%6055!5%532('LF`(``&1(BP0E*````$B)
MA"2(`@``,<!(B>),C8PD@````$B)UP\?@`````!!BP!-BQ!(@\<028/`"`_(
MB<!,B=%(B4?P3(G02,'I($C!Z"A)P>HX)0#_``!,"=!)B<I(P>$(2<'B&('A
M``#_`$6)TDP)T$@)R$B)1_A,.<]UK68/;T0D$&8/;UPD($B-1"1H2('":`(`
M`&8/;U0D,&8/;RV'A@``#Q^``````/,/;PAF#V_B9@]O4-A(@\`09@_O0(AF
M#^_*9@_OP68/;\AF#W/0'V8/<_$!9@_KP68/V\4/*4`(9@]OPV8/;]Q(.=!U
MNTR+#DR+7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D
M2(V,"YEY@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)
MB?I("<),B=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD
M"$R)R$R)R4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),
M`=)-B>))P>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ
M38G52#'0B==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L
M`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(
MP>$%3`GI3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G!
M[1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/
MC:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML
M)#A!`=1(B<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X
M3#'`3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"
M6D@)^$V)U4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)
MXDG![`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(
M3(G!2,'A!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(
M,<))P>T;08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B
M'HG_3XVD+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)
M[$R+;"1@00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)
MP4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$
M*)EY@EI("?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!
M`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q
M^D@!RDR)P4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G2
M28G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`
M2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)
M_$G!Y`5-">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL
M2#'02<'L&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@
M'DC![P)%B=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!
MX`5-">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,
M*9EY@EI-B>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!
MB<5,"=%-B<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J
M&TC!X@5,"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#
MC"2P````23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH
M2<'M`DC!X!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,
MB<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4Q
MXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB
M3`G"28G(2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)
MP>@;2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````
M2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!
MX1Y$B>=,"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;
M2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````
M13'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%
MB>!("?A(B=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A
M!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B
M3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),
M"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)
MP(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD
M.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)
MB<*)P$@#A"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG2
M20'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G0
M2<'H&TC!X`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)
MTD@#E"08`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-
M3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(
MB?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQ
MT$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"
M18GH2`.,)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,
MB<=)P>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$
M)#@!``!%,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!
MXAY%B=),"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(
MP>`%3`G`1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+
ME"1``0``2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B
M'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I
M38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTA
MYDPAPDP)\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)
MXDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!
M\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!
MB<U)"<Y)(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;
M30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H
M`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A
M'D6)Y$P)T4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE
M2<'N&TG!Y05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPA
MX4P)\4R+M"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)
MX4G![`)(P>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)
M_DP!TDF)^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!
MB=5((?E-(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP
M28G600'(2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``
M20'&30'T38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)
MTD@)T4F)UD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N
M&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)
M\DR+M"2@`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(
MP>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!
MT4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)
M(?Y,(>I,"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'0
M2(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&
M30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)
MT4D)SD&)RDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!
MY05-"?5!`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+
MA"3(`0``20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)
MT4C!YQY,">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38
M`0``2`'*3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/
M28G-08G.3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,
M">B)P$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"
M3`'B38GL2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB
M38G$B=%%B<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%
M30GT38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ
M[D0Q\DV)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)
MRD2)T4V)ZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,
M"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(`
M`$4QZ$V)U4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)
MQ4P)\4R+M"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,
M"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(`
M`$4QX$V)]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)
MQ$P)ZDR+K"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,
M">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(`
M`$4QT$V)ZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!
MQTP)X4R+I"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,
M">*)TD@!UTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(`
M`$4Q\$V)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)
MTDR+E"0X`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,
M"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(`
M`$4QZ$V)U4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)
M\4R+M"1(`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,
M"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQ
MTDD!QT0QPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)
MX$P)ZDR+K"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,
M">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(`
M`$4QXDV)[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-
M">!,BZ0D:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'7
M3(G22<'L&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-
M`?Q%B<!$,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))
MP>0>B<E-">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)
M3@@!^$R)5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D
M2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^B&Y?__9@\?1```05=!5D%5
M05154TB#[`A(A?\/A+$```!(BP4RCP``3(LP387V#X2>````#[8'28G_28GU
MA,!T!#P]=55%,>1)BQY(A=MT,$UCY$R)]0\?0`!,B>),B?Y(B=_H8N/__X7`
M=0="@#PC/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```
M````28G\00^V1"0!28/$`83`=`0\/77N12G\ZY1F#Q]$``!,*?5*C5PC`4C!
M_0-!B6T`Z[1F#Q]$```QV^NJ#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$
M))@````QP$B)YNBZY/__A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>
MO@(```!(B=_H_^3__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@`
M``!U"4B!Q*````!;P^@MY/__9F8N#Q^$``````!FD$%455-,C9PD``#__TB!
M[``0``!(@PPD`$PYW'7O2(/L$+H"````,?9D2(L$)2@```!(B80D"``!`#'`
M08G\2(GCZ$KD__](C6C_2(GJ2,'Z/TC!ZC!(C405``^WP$@IT$@IQ0^(FP``
M``\?@``````QTDB)[D2)Y^@3Y/__N@@``0!(B=Y$B>?HP^'__TB82(/X!W9;
M2(U$`_A(.=AR44B-%;J-``#K$0\?A```````2(/H`4@YV'(W2(L*2#D(=>](
M*=A(`>A(BY0D"``!`&1(*Q0E*````'4S2('$$``!`%M=05S#9BX/'X0`````
M`$B![0```0!(@?T``/__#X5L____2,?`_____^NZZ`[C__]F9BX/'X0`````
M``\?`$%505154TB![*@```!D2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(
MB?MU*TB+A"28````9$@K!"4H````#X4C`0``2('$J````%M=05Q!7<-F#Q]$
M``#HL^'__TB)Q4B%P'3(2(GOZ(/C__](A<`/A+(```"`>!,N3(U@$W4008!\
M)`$`=-T/'X0``````(!X$RX/A*8```!(B=_H3N'__TR)YTF)Q>A#X?__08U\
M!0)(8__HEN#__TV)X4F)V+X!````28G%2(G',<!(Q\+_____2(T-62P``.BP
MXO__3(GO2(GFZ!7A__],B>^#^/]T$(M$)!@E`/```#T`0```=%WH>.#__TR)
M[^C0X/__2(GOZ-CB__](A<`/A57___\/'X``````2(GOZ%#B__](B=_H6.#_
M_^GP_O__#Q\`08!\)`$N#X5.____08!\)`(`#X0-____Z3W___\/'P#HF_[_
M_^NAZ)3A__\/'T``\P\>^E-(BQV$BP``2(T-M6P``$B--;`K``!(BQ5WBP``
M9$B+.^@FXO__9$B+.TR-!2LM``!;2(T5HQ4``$4QR4R)P4B--9PK``#I<>#_
M_Y!!54%455-(@>P`$```2(,,)`!(@^P8NO\/``!D2(L$)2@```!(B80D"!``
M`#'`28GD2(G[2(GU2(T];2L``$R)YNB*X/__A<!^$HG!@^@!2&/0@#P4`'5(
MA<!U/$B+!=V*``!(B>I(B=YD2(LXZ&[?__](BX0D"!```&1(*P0E*````'5.
M2('$&!```%M=05Q!7<,/'T0``(G!9@\?1```3&/IOB\```!,B>=,B>KH?=[_
M_TB%P'2D2(L%@8H``$R)Z4R)XDB)WF1(BSCH[]___^N?Z&C@__\/'X0`````
M`$%7059!54%454B)]5-(B?M(@^PH9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`
M2`'%2(GOZ!G?__](C70D%$B)WTF)Q#'`Z)?Z__](A<`/A`8!``!(B<=)B<7H
M\][__TPYX`^#T@```$AC3"043(LUOHD``$R-/,T`````#[8#A,`/A*,!```\
M/0^$FP$``$B)V`^V4`%(@\`!A-)T!8#Z/77O2"G82)A-BRY*C7P@`NC]W?__
M30']28E%`$B%P'1228L&2(U+`4J+%#@/M@.(`H3`="(\/74-ZQP/'X``````
MA,!T$0^V`4B#P@%(@\$!B`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(@\`!
MA,EU[TB+1"089$@K!"4H````#X47`0``2(/$*%M=05Q!74%>05_##Q]``#'`
M9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[T/'T``3(LUT8@``$V+!DF#.``/
MA,,```!,B<!%,>UF#Q]$``!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+
M!2>)``"%P'5C2(GW3(E$)`C'!1&)```!````Z/S<__](B<=(A<`/A%'___])
M8\U(BW0D"$R-/,T`````3(GZZ"C>__])B09(B<=!C44!1(EL)!1(F$C'!,<`
M````Z83^__]F+@\?A```````3(G'Z`C?__])B09(B<=(A<`/A/K^__])8\U,
MC3S-`````.NZ#Q]``#'`Z7?^__^^$````$4Q[>E7____Z!_>__]F9BX/'X0`
M``````\?0`#S#Q[Z2(L%!8@``$B+%0:(``!(C0TO:0``2(TU*B@``&1(BSCI
MI][__P\?@`````#S#Q[Z55-(@>P`$```2(,,)`!(@>P`$```2(,,)`!(@^PH
M9$B+!"4H````2(F$)!@@```QP$B-G"00$```2(GEZ$O<__^Z`1```$B)W[X!
M````08G`3(T-^B<``#'`2(T-]2<``.@&WO__N@`0``!(B>Y(B=_H]MS__X7`
M>%"->`%(B<-(8__HI-O__TB%P'0]2&/;2(GN2(G'2(G:Z![>___&!!@`2(G!
M2(N$)!@@``!D2"L$)2@```!U#4B!Q"@@``!(B<A;7</H$MW__S')Z]=F9BX/
M'X0```````\?`/,/'OKI%____P\?@`````#S#Q[Z05=!5D%505154TB![``0
M``!(@PPD`$B![+@```!D2(L$)2@```!(B80DJ!```#'`28G\2(GS2(T]-R<`
M`$B-="0,Z"7W__^^+P```$R)YTB)Q>A%W/__2(7`=$`QP$R)YDB-/14G``#H
M'_S__TR)X$B+E"2H$```9$@K%"4H````#X6"`0``2('$N!```%M=05Q!74%>
M05_##Q\`2(G?3(TMY"8``$R--<HG``#H&MS__TR)[DB)Q^A/W/__2(G#2(7`
M=)>`.P`/A.0```!F#Q]$``!(A>UT$TB)WDB)[^@8W/__A<`/A*<```!(B=_H
MZ-K__TB-5`/_28G'2#G3<A?K)68/'X0``````,8"`$B#Z@%(.=-T!8`Z+W3O
M2(G?Z+?:__])B<=,B>?HK-K__TF-1`<!2#W_#P``#X<;____3(V\)*````!,
MB?%)B=@QP$B#[`BZ`!```+X!````3(G_051,C0TA)@``Z`S<__](C70D($R)
M_^AOVO__6EF%P'40BT0D*"4`\```/0"```!T24R)[C'_Z&_;__](B<-(A<`/
MA+/^__^`.P`/A2+___](A>UT!H!]`"YT%T&_`0```$B-':@E``#I6?___P\?
M1```@'T!`'2YZ^&^`0```$R)_^BCV___A<!UIDR)_DB-/88E``#HD/K__TR)
M_^C(VO__Z6?^___HWMK__V9F+@\?A```````#Q\`\P\>^E.^+P```$B)^^@.
MVO__2(U0`4B%P$@/1=I(B=];Z8K:__]F+@\?A```````\P\>^E532('L`!``
M`$B##"0`2(/L&&1(BP0E*````$B)A"0($```,<!(A?\/A,X```"`/P!(B?L/
MA,(```#H3=G__TB-4`%(@?H`$```#X?D````2(GE2(GO@_H(<@Z)T4B)WL'I
M`_-(I4B)\S')]L($=`F+"XD/N00```#VP@)T#D0/MP0+9D2)!`](@\$"@^(!
M=`</MA0+B!0/2(U$!?](.<5R%NL9#Q^$``````#&``!(@^@!2#GH=`6`."]T
M[[XO````2(GOZ"+9__](A<!T+4@YQ7)82(GOZ*#9__](BY0D"!```&1(*Q0E
M*````'5)2('$&!```%M=PP\?`$B+A"0($```9$@K!"4H````=2E(@<08$```
M2(T]!20``%M=Z5C9__\/'X0``````,8``.NC#Q\`,<#KI.A?V?__9F8N#Q^$
M```````/'T``\P\>^D%7059!54%454B-+=XC``!32(/L&&1(BP0E*````$B)
M1"0(,<!(C5PD!&:0,<!(B=Y(B>_HD_/__TB%P'0^2(L%UX(``$AC5"0$2(L`
M2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$
M``!(C2UT(P``9@\?A```````,<!(B=Y(B>_H,_/__TB%P'0^2(L%=X(``$AC
M5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7P
MZ[9F#Q]$``!(C2T<(P``9@\?A```````,<!(B=Y(B>_HT_+__TB%P'0^2(L%
M%X(``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)
M$$B%TG7PZ[9F#Q]$``!(C2W%(@``9@\?A```````,<!(B=Y(B>_H<_+__TB%
MP'0^2(L%MX$``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$``!(C2UL(@``9@\?A```````,<!(B=Y(B>_H
M$_+__TB%P'0^2(L%5X$``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@```
M``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C24<(@``9@\?A```````,<!(
MB=Y,B>?HL_'__TB%P'0^2(L%]X```$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)T
MSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C25Q(0``9@\?A```
M````,<!(B=Y,B>?H4_'__TB%P'0^2(L%EX```$AC5"0$2(L`2(T$T$B+4`A(
MB1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C35H(0``
M9@\?A```````,<!(B=Y,B??H\_#__TB%P'0^2(L%-X```$AC5"0$2(L`2(T$
MT$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,
MC2T2(0``9@\?A```````,<!(B=Y,B>_HD_#__TB%P'0^2(L%UW\``$AC5"0$
M2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$``!,C3V\(```9@\?A```````,<!(B=Y,B?_H,_#__TB%P'0^2(L%=W\`
M`$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%
MTG7PZ[9F#Q]$``!,C3WZ'P``9@\?A```````,<!(B=Y,B?_HT^___TB%P'0^
M2(L%%W\``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`
M"$B)$$B%TG7PZ[9F#Q]$``!(B=Y(C3T#(```Z('O__](A<!T#4B)QDR)[S'`
MZ(_T__\QP$B)WDB-/?$?``#H7N___TB%P'012(G&2(T][Q\``#'`Z&CT__](
MB=Y(C3WI'P``,<#H-^___TB)QDB%P'0Y3(GG,<#H1?3__TB+1"0(9$@K!"4H
M````=41(@\082(GO2(TUTQ\``#'`6UU!7$%=05Y!7^D6]/__,<!(B=Y(C3VE
M'P``Z.7N__](A<!TNTB)QDR)]S'`Z//S___KK.A,U/__9F8N#Q^$``````"0
M\P\>^DB#[!A(C3T0'P``9$B+!"4H````2(E$)`@QP$B-="0$Z)?N__](A<!T
M,@^V$(#Z,`^4P(32#Y3""="#\`$/ML!(BU0D"&1(*Q0E*````'402(/$&,,/
M'X``````,<#KX.C7T___#Q^``````/,/'OI(@^P(Z`/4__^)Q^A\TO__2(7`
M=`-(BP!(@\0(PV9F+@\?A```````#Q]``/,/'OI!54%43(TEWQX``%5(B?U,
MB>=32(/L&&1(BP0E*````$B)1"0(,<!(C70D!.CK[?__2(7`=`B`.`!(B<-U
M+DB+1"0(9$@K!"4H````#X6P````2(GN2(/$&$R)YS'`6UU!7$%=Z=/R__\/
M'P!(B>Y(B<?HE=+__TB%P'0@2(M$)`AD2"L$)2@```!U=DB#Q!A;74%<05W#
M#Q]$``!(B>_HZ-'__TB)WTF)Q>C=T?__28U\!0+H,]'__TB#[`A)B>B^`0``
M`%-(Q\+_____2(G'28G%3(T-8!T``$B-#48>```QP.A$T___6%I(BT0D"&1(
M*P0E*````'4(3(GNZ5/____HE=+__P\?1```\P\>^D%72(T5Z!T``$B-#94=
M``!!5F9(#V["2(T5I!T``$F)_D%52(T]ZAP``$%455-(@>PX`0``9$B+!"4H
M````2(F$)"@!``!(C07%'```2(UL)!1(QT0D4`````!(QX0DB`````````!(
MB>Y(QT0D,`````!F2`]NR$B-!7<=``!F#VS!9D@/;M!(C05O'0``#RE$)$!F
M2`]NP69(#V[82(T-71T``&8/;,)(C057'0``#Q%$)&AF2`]NPF9(#V[@,<!F
M#VS##Q%$)'AF2`]NP68/;,0/*40D(.@O[/__2(7`=`R`.`!(B<,/A78$``#H
MV='__XG'Z%+0__](A<`/A.D#``!,BR!-A>0/A-T#``!,B>?H9=#__TB-?``!
MZ+O/__]%#[8$)$F)QTB)PT6$P'0Z3(TMV!P```\?0`!%#[;`3(G_3(GIO@$`
M``!(Q\+_____,<!)@\0!28/'`NB[T?__10^V!"1%A,!UT4R-;"1@2(T]-1P`
M`.L0#Q\`28M]"$F#Q0A(A?]T,TB)[C'`Z'GK__])B<1(A<!TX8`X`'3<2(G'
MZ#3L__^%P'303(GGZ+C0__])B<=(A<!U0$R-9"1`38L\)$V%_W0R08`_``^$
M"`,``$R)_^@`[/__A<`/A0@!``!-BWPD"$F#Q`A-A?]UV&8N#Q^$``````!,
MB?_H>,___TB)WTF)Q.AMS___18VD!`0$``!-8^1,B>?HNL[__U--B?A,C0W_
M&@``28G%2(T%YQL``+X!````2,?"_____U!(C0W*&P``3(GO,<#HQ]#__TR)
M[[[``0``Z"K1__]?05B#^/]U$NCMS___1(L(08/Y$0^%N0(``$B-A"20````
M3(GO2(G&2(D$).@IT/__B<.%P'1S2(L%!'H``$F+#DV)Z$B-%1\<``"^`0``
M`$B+.#'`Z-#-__]%,>1(BX0D*`$``&1(*P0E*`````^%`00``$B!Q#@!``!,
MB>!;74%<05U!7D%?PY!,B?])@\0(Z'3/__])B<=(A<`/A+W^___I\_[__P\?
M`(N$)*@````E`/```#T`0```#X5V____1(N\)*P```#HG,___T$YQP^%8/__
M_XN$)*@````E_P$``#W``0``#X5)____3(GGZ(3-__](B>Y(C3V#&@``28G$
M,<#HH.G__TB%P`^$3P(``$F+/DB)QN@<\O__28G'2(7`#X0X`@``3(G_Z.C-
M__](B<*#^`-^0$B82(TU?AH``$B)5"0(28U\!_SHZ,[__X7`=21(BU0D"(/Z
M!`^$U@(``(U"^TB808`\!R\/A,8"``!F#Q]$``!(B>Y(C2V%&0``,<!(B>_H
M'.G__TB%P`^$TP$```^V`(3`#X3(`0``/#`/A,`!``!(B>](C37"&0``,<#H
M#^[__TB-+3@:``!,C34?&@``Z`S-__]52,?"_____TV)Z%!,C0WI&```O@$`
M``!,B>=(C0WJ&0``,<#HP\[__UA:ZT</'X``````Z//-__^#.!%U2.C)S/__
M@\,!2(/L"$V)Z%5,C0VG&```3(GQO@$```!32,?"_____TR)YU`QP.A\SO__
M2(/$(+[``0``3(GGZ-O.__^#^/]TKDR)[^BNS/__3(GF2(T]3!@``#'`Z%WM
M__],B>?H%?K__^GC_?__13'_Z1C]__\/'X0``````$B-7"0@ZPUF#Q^$````
M``!(@\,(2(L[2(7_#X20````,<!(B>[H]N?__TB%P'3A@#@`=-Q(B<?H1,W_
M_TF)Q$B%P'3,Z=K[__](BP5H=P``28L.38GH2(T50QD``+X!````2(LX,<#H
M-,O__^E?_?__#Q^``````$B)Q^B`^?__2(N$)"@!``!D2"L$)2@````/A50!
M``!(@<0X`0``2(G?6UU!7$%=05Y!7^G0S/__OPT```!,C25"&```Z"_+__]!
MN%,```!)B<=(B</I<_O__V8/'T0``$V+/NG`_?__,?9,B?\QP.@4S/__08G&
MA<`/A"G^__^)Q^B"Z/__28G'2(7`#X@6_O__,=)(C7#V1(GWZ/C,__](C70D
M&KH&````1(GWZ*;*__^!?"0:`$-!0P^%Z/W__V:!?"0>2$4/A=O]__])C7?.
M,=)$B??HO<S__TB+'"2Z*````$2)]TB)WNAIRO__O@$```!-B>A,B>=(C07W
M%P``QH0DN`````!(C0VY%P``2,?"_____U!,C0VI%@``,<!3Z)',__]97NDD
M_O__9BX/'X0``````$V+=@A-A?8/A#/]__],B??HR\K__TB#^`,/AB']__])
MC7P&_$B--6$7``#HT,O__X7`30]$_ND%_?__Z+#+___S#Q[Z051(C3UF%@``
M55-(@^P02(L=EG4``&1(BP0E*````$B)1"0(,<!,C60D!$R)YF1(BRL/MH6P
M````B(6Q````,<#HYN7__TB%P'0)@#@Q#X1H`0``,<#H`?+__V1(BRM(B>^Y
M`P```+H!````2(TU"!<``.BDR?__2(G%2(7`="A(BT`09$B+.TB-%>X6``!(
MBS#HM<G__TB+11!(BS#V1@Y`#X5$`0``9$B+.[D#````N@$```!(C37%%@``
MZ%K)__](B<5(A<!T+4R)YDB-/6D5```QP.A1Y?__2(G"2(7`#X3E````2(M%
M$&1(BSM(BS#H5<G__V1(BSNZ`0```$B--7T6``#H<,C__V1(BSM(C16"%@``
M2(G&Z"W)__]D2(L#3(GF2(T]!Q4``,:`L0`````QP.CQY/__2(D%VG0``$B)
MPTB%P'1"OL`!``!(B=_H5<O__XU0`8/Z`78)@_@1#X62````2(M$)`AD2"L$
M)2@````/A9L```!(@\006UU!7,,/'X``````2(L]D70``.B$]___2(D%?70`
M`$B)PTB%P'6C2(T]EA8``#'`Z$?*__\/'X``````@'@!``^$F?[__^F)_O__
MD$B+!5%T``!(BS!(BT402(LXZ(KH___I$/___P\?1```9$B+.^BGR?__Z:[^
M__^)P4B+!2%T``!(B=I(C3U?%@``2(LP,<#HY<G__^B0R?__\P\>^E5(B?U3
M2(/L&&1(BP0E*````$B)1"0(,<#HSN[__[XO````2(G'2(G#Z*[(__](A<!(
MC5`!2`]%VDB)W^@KR?__2(UT)`1(C3T>%```2(G#,<#HM>/__TB%P'0@#[80
MA-(/E,"`^C`/E,((T'4.2(7M=`F`?0``=2,/'P!(BT0D"&1(*P0E*````'5&
M2(/$&%M=PV8/'X0``````+H$````2(TU=A0``$B)W^@<Q___A<!UR$B+1"0(
M9$@K!"4H````=0Y(@\082(GO6UWINN7__^BUR/__#Q]$``#S#Q[Z2(/L"+^`
M````Z.[&__]F#V\%]E,``$C'0#``````#Q$`9@]O!?-3``#'0'@`````#Q%`
M$&8/;P7P4P``#Q%`($B#Q`C##Q^``````/,/'OI!5TACPD%628G&055!5$F)
M_%5(C6\X4TB)\TB#[`A(BW<H2(M7,(T,QD@Y\4B)3RA(@](`2,'H'4@!T$B)
M1S!(8T=XA<`/A>D```!!@_X_#XXG`0``08/N0$6)]T'![P9%C6\!2<'E!DD!
MW9#S#V\#3(GG2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#H
MT<O__TPYZW7,0<'G!D4I_DECQDB#^`AR7$F+50!(C4T(2(/A^$F)5"0X28M4
M!?A(B50%^$@IS4@!Z$DI[4B#X/A(@_@(<AA(@^#X,=))BW05`$B)-!%(@\((
M2#G"<NY%B70D>$B#Q`A;74%<05U!7D%?PV:0J`1U=$B%P'3A00^V50!!B%0D
M.*@"=--!#[=4!?YFB50%_NO&#Q]``$&_0````$B-?`4`2(G>02G'13GW10]/
M_DUC[TR)ZNCEQ___08M$)'A$`?A!B40D>(/X0'623(GG12G^3`'KZ/7*___I
MS_[__TF)W>DC____08M5`$&)5"0X08M4!?R)5`7\Z5O___^0\P\>^D%63(UV
M.$%505152(G]4TR+;BA(B?-,BV8P3(GH2,'H`X/@/XU(`4B8QD0&.(!(8\%,
M`?"#^3@/CG\!``"^0````"G.=`\QTHG1@\(!Q@0(`#GR<O-(B=_H;\K__V8/
M[\`/$4,X2<=&,`````!!#Q%&$$$/$48@3(GB00^VQ4R)[TR)[DC!ZAA(P>`(
M3(GA2,'O$$F)T$R)ZDC![A@/MM9`#[;_0`^V]DC!Z1!("=!,B>(/MLE(P>`(
M2`GX#[;^00^VT$C!X`A("?!!#[;T2,'@"$@)\$C!X`A("?A(B=](P>`(2`G(
M2,'@"$@)T$B)0W#HULG__TB+`TB)WTC!Z!B(10!(BP-(P>@0B$4!2(L#B&4"
M2(L#B$4#2(M#"$C!Z!B(101(BT,(2,'H$(A%!4B+0PB(909(BT,(B$4'2(M#
M$$C!Z!B(10A(BT,02,'H$(A%"4B+0Q"(90I(BT,0B$4+2(M#&$C!Z!B(10Q(
MBT,82,'H$(A%#4B+0QB(90Y(BT,8B$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%
M$4B+0R"(91)(BT,@B$436UU!7$%=05[IYL/__V8/'T0``+HX````,?\IRH/Z
M"')"B=%(QP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"@O[_
M_X/B^#'`B<:#P`A(B3PQ.=!R\^EK_O__]L($=2.%T@^$7O[__\8``/;"`@^$
M4O[__S')9HE,$/[I1O[__P\?`,<``````,=$$/P`````Z3#^__\/'T0``/,/
M'OI(BPV=;@``Z8#"___S#Q[Z2(/L"$B#Q`C#````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`,0!,1%],24)205)97U!!5$@`4UE35$5-
M`"]T;7``5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X`"5S)7,E<R5S
M`'!A<BT`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`
M)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/
M3@`Q+C`U-P`M90`M+0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO
M=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@
M("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-
M04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM
M>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@
M+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@
M:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P
M*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D
M:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G
M;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@
M>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*
M?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?
M1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP
M86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)
M3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]
M("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@
M9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^
M>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D
M:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O
M=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@
M("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H
M)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E
M9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A
M<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P
M87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T
M;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U
M<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A
M;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*
M?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS
M:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q
M(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO
M9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H
M95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?
M:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I
M;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A
M<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D
M<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=
M('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@
M8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO
M861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE
M>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D
M9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K
M97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@
M/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN
M72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L
M("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z
M("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA
M;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I
M;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I
M;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*
M)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)
M3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B
M72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L
M96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A
M9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*
M<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N
M86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O
M9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@
M;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D
M:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET[
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@
M=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D
M9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A
M9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ
M92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@
M/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L
M;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@
M)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@
M)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```````$-!
M0TA%``!P97)L>'-I+F,```````````````````#_____`````/____\`````
M`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````````
M`````1L#._P````>````P&[__S`!```@<O__6`$``#!R__]P`0``@'7__WP&
M``"0=___&`$``(!X__^(`0``\([__]@!``#`C___)`(``%"0__](`@``<)'_
M_X@"``#@DO__Q`(``#"3___@`@``$)3__R`#``!@EO__;`,``)"6__^``P``
M<)?__[0#``"`E___R`,``*"9__\L!```T)G__T@$```@F___A`0``#"@___0
M!```H*#__^P$``#0H/__!`4``."A__]@!0``P*C__Q`&``#@JO__1`8``,"K
M__^H!@``$*S__\`&``"PK?__#`<```"P__]0!P```````!0``````````7I2
M``%X$`$;#`<(D`$``!0````<````<';__R8`````1`<0`````"0````T````
MB&W__V`#````#A!&#AA*#PMW"(``/QHY*C,D(@`````4````7````,!P__\0
M```````````````4````=````+AP__]0`P````````````!,````C````/!V
M__]J%@```$(.$(\"20X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#0A8*
M#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```$@```#<````$(W__\P`````0@X0
MCP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"
M#AA"#A!"#@A)"P`@````*`$``)2-__^#`````$$.$(,"2@ZP`0)Q"@X000X(
M00L\````3`$```".__\2`0```$(.$(P"00X8A@-!#B"#!$@,"Z"`!%$-!T0.
ML(`$`L`*#B!!#AA!#A!"#@A+"P``.````(P!``#@CO__;`$```!"#A"-`D(.
M&(P#00X@A@1!#BB#!4<.T`%^"@XH00X@00X80@X00@X(1PL`&````,@!```4
MD/__3P````!%#A"#`G$."````#P```#D`0``2)#__]@`````0@X0C0)"#AB,
M`T$.((8$00XH@P5'#J@@20[`(`)V"@XH00X@00X80@X00@X(1@M(````)`(`
M`.B0__]!`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#!T<.8`,5
M`0H..$$.,$$.*$(.($(.&$(.$$(."$4+$````'`"``#LDO__*0`````````P
M````A`(```B3___2`````$4.$(8"00X8@P-'#I@@3`Z80$D.P$`"H0H.&$0.
M$$$."$$+$````+@"``"TD___"0````````!@````S`(``+"3__\2`@```$8.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.N"!,#O`A`G$*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A$"P*Y#O@A3PZ`(EH.^"%!#O`A````&````#`#``!L
ME?__)@````!%#A"#`EP."````#@```!,`P``@)7__T$!````10X0A@)!#AB#
M`T<.F"!)#K`@`N0*#AA!#A!!#@A$"UH*#AA(#A!!#@A-"T@```"(`P``E);_
M_P0%````1@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D@..(,'1`Y0`Z8$"@XX
M30XP00XH0@X@0@X80@X00@X(10L8````U`,``%B;__]I`````$@.(`)0"@X(
M2`L`%````/`#``"LF___(0````!(#A!8#@@`6`````@$``#$F___"P$```!&
M#A"-`D(.&(P#2`X@A@1'#BB#!40.0`)""@XH1@X@00X80@X00@X(2`MD"@XH
M00X@00X80@X00@X(1@MA#DA)#E!C#DA!#D````"L````9`0``'B<___@!@``
M`$8.$(\"4`X8C@-1#B"-!$D.*(P%00XPA@9!#CB#!T<.\`(#[@$.^`)A#H`#
M7P[X`D(.\`(">`H..$0.,$$.*$(.($(.&$(.$$(."$(+`T4!#O@"2PZ``UX.
M^`)!#O`"7P[X`D0.@`-0#H@#2PZ0`TL.\`("Y@H..$0.,$$.*$(.($(.&$(.
M$$(."$4+`N`.^`)*#H`#1@[X`D$.\`(``#`````4!0``J*+__R`"````1@X0
MC`)(#AB&`T$.((,$1`XP`W$!"@X@00X800X00@X(2`LT````2`4``)2D___;
M`````$4.$(8"1`X8@P-$#C`"APH.&$$.$$$."$H+;`H.&$0.$$$."$4+`"@`
M``"`!0``_&[__Q`"````10X0A@)!#AB#`T0.4`-K`0H.&$,.$$$."$$+%```
M`*P%```0I?__20````!(#A`"0`X(2````,0%``!(I?__GP$```!&#A"/`D4.
M&(X#10X@C01"#BB,!40.,(8&10XX@P='#D`"X0H..$$.,$$.*$(.($(.&$(.
M$$(."$,+`$`````0!@``G*;__TL"````1@X0C@)&#AB-`T(.((P$00XHA@5$
M#C"#!@.;`0H.*$$.($(.&$(.$$(."$L+````````$````%0&``"HJ/__$```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#0*0```````)`I`````````0````````#-
M`@````````$`````````W0(````````,```````````@````````#0``````
M``!P80```````!D`````````T,L````````;``````````@`````````&@``
M``````#8RP```````!P`````````"`````````#U_O]O`````+`#````````
M!0`````````P#0````````8`````````D`0````````*`````````%X$````
M````"P`````````8`````````!4````````````````````#`````````.#-
M`````````@````````#X!````````!0`````````!P`````````7````````
M`$@4````````!P````````#($@````````@`````````@`$````````)````
M`````!@`````````'@`````````(`````````/O__V\``````0``"`````#^
M__]O`````$@2````````____;P`````!`````````/#__V\`````CA$`````
M``#Y__]O``````0`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#@RP`````````````````````````````P(````````$`@````
M````4"````````!@(````````'`@````````@"````````"0(````````*`@
M````````L"````````#`(````````-`@````````X"````````#P(```````
M```A````````$"$````````@(0```````#`A````````0"$```````!0(0``
M`````&`A````````<"$```````"`(0```````)`A````````H"$```````"P
M(0```````,`A````````T"$```````#@(0```````/`A`````````"(`````
M```0(@```````"`B````````,"(```````!`(@```````%`B````````8"(`
M``````!P(@```````(`B````````D"(```````"@(@```````+`B````````
MP"(```````#0(@```````.`B````````\"(`````````(P```````!`C````
M````(",````````P(P```````$`C````````4",```````!@(P```````'`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T`````````I005(N<&T*``````````#8
M<@```````$=#0SH@*%5B=6YT=2`Q,BXR+C`M,3!U8G5N='4Q*2`Q,BXR+C``
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YP;'0N<V5C`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````!@#````````&`,`````
M```<`````````````````````0```````````````````!,````'`````@``
M```````X`P```````#@#````````,`````````````````````@`````````
M```````````F````!P````(`````````:`,```````!H`P```````"0`````
M```````````````$````````````````````.0````<````"`````````(P#
M````````C`,````````@````````````````````!```````````````````
M`$<```#V__]O`@````````"P`P```````+`#````````W``````````&````
M``````@```````````````````!1````"P````(`````````D`0```````"0
M!````````*`(````````!P````$````(`````````!@`````````60````,`
M```"`````````#`-````````,`T```````!>!````````````````````0``
M`````````````````&$```#___]O`@````````".$0```````(X1````````
MN``````````&``````````(``````````@````````!N````_O__;P(`````
M````2!(```````!($@```````(``````````!P````$````(````````````
M````````?0````0````"`````````,@2````````R!(```````"``0``````
M``8`````````"``````````8`````````(<````$````0@````````!(%```
M`````$@4````````^`0````````&````&`````@`````````&`````````"1
M`````0````8``````````"``````````(````````!L`````````````````
M```$````````````````````C`````$````&`````````"`@````````("``
M``````!@`P``````````````````$``````````0`````````)<````!````
M!@````````"`(P```````(`C````````$````````````````````!``````
M````$`````````"@`````0````8`````````D",```````"0(P```````%`#
M```````````````````0`````````!``````````J0````$````&````````
M`.`F````````X"8```````"0.@``````````````````$```````````````
M`````*\````!````!@````````!P80```````'!A````````#0``````````
M``````````0```````````````````"U`````0````(``````````'``````
M````<````````&!!```````````````````0````````````````````O0``
M``$````"`````````&"Q````````8+$```````#\````````````````````
M!````````````````````,L````!`````@````````!@L@```````&"R````
M````:`8```````````````````@```````````````````#5````#@````,`
M````````T,L```````#0NP````````@````````````````````(````````
M``@`````````X0````\````#`````````-C+````````V+L````````(````
M````````````````"``````````(`````````.T````&`````P````````#@
MRP```````."[``````````(````````'``````````@`````````$```````
M``";`````0````,`````````X,T```````#@O0```````"`"````````````
M```````(``````````@`````````]@````$````#``````````#0````````
M`,`````````H````````````````````"````````````````````/P````(
M`````P`````````HT````````"C`````````*`````````````````````@`
M```````````````````!`0```0```#`````````````````````HP```````
M`"8````````````````````!``````````$``````````0````,`````````
M````````````````3L`````````*`0```````````````````0``````````
'````````````
